import { analyzeCommits as upstreamAnalyzeCommits, } from '@semantic-release/commit-analyzer';
import log from 'git-log-parser';
import getStream from 'get-stream';
Object.assign(log.fields, { hash: 'H' });
export async function analyzeCommits(pluginConfig, context) {
    /** Simple lookup table; when a commit matches the desired subtree, add it to this lookup. */
    const lookup = {};
    const { subtree, getCommitList = defaultGetCommitList, ...restConfig } = pluginConfig;
    context.logger.log('Filtering commits by subtree: {%s}', subtree.join(', '));
    const { lastRelease: { gitHead: from = null } = {}, nextRelease: { gitHead: to = 'HEAD' } = {}, cwd, env = {}, } = context;
    const commits = getCommitList(from, to, subtree, cwd, env);
    for (let commit of await commits) {
        lookup[commit.hash] = true;
    }
    const filteredCommits = context.commits.filter(({ hash }) => hash in lookup);
    context.logger.log('Found %d commits matching subtree', filteredCommits.length);
    return upstreamAnalyzeCommits(restConfig, {
        ...context,
        commits: filteredCommits,
    });
}
function defaultGetCommitList(from, to, subtree, cwd, env) {
    return getStream.array(log.parse({
        _: [from ? `${from}..${to}` : to, '--', ...subtree],
    }, { cwd, env: { ...process.env, ...env } }));
}
